@@ -90,31 +90,55 @@ class PathToFileURITest(unittest.TestCase):
             result = path.path_to_uri('/tmp/æøå')
             self.assertEqual(result, 'file:///tmp/%C3%A6%C3%B8%C3%A5')
 
+    def test_utf8_in_path(self):
+        if sys.platform == 'win32':
+            result = path.path_to_uri('C:/æøå'.encode('utf-8'))
+            self.assertEqual(result, 'file:///C://%C3%A6%C3%B8%C3%A5')
+        else:
+            result = path.path_to_uri('/tmp/æøå'.encode('utf-8'))
+            self.assertEqual(result, 'file:///tmp/%C3%A6%C3%B8%C3%A5')
+
+    def test_latin1_in_path(self):
+        if sys.platform == 'win32':
+            result = path.path_to_uri('C:/æøå'.encode('latin-1'))
+            self.assertEqual(result, 'file:///C://%E6%F8%E5')
+        else:
+            result = path.path_to_uri('/tmp/æøå'.encode('latin-1'))
+            self.assertEqual(result, 'file:///tmp/%E6%F8%E5')
+
 
 class UriToPathTest(unittest.TestCase):
     def test_simple_uri(self):
         if sys.platform == 'win32':
             result = path.uri_to_path('file:///C://WINDOWS/clock.avi')
-            self.assertEqual(result, 'C:/WINDOWS/clock.avi')
+            self.assertEqual(result, 'C:/WINDOWS/clock.avi'.encode('utf-8'))
         else:
             result = path.uri_to_path('file:///etc/fstab')
-            self.assertEqual(result, '/etc/fstab')
+            self.assertEqual(result, '/etc/fstab'.encode('utf-8'))
 
     def test_space_in_uri(self):
         if sys.platform == 'win32':
             result = path.uri_to_path('file:///C://test%20this')
-            self.assertEqual(result, 'C:/test this')
+            self.assertEqual(result, 'C:/test this'.encode('utf-8'))
         else:
             result = path.uri_to_path('file:///tmp/test%20this')
-            self.assertEqual(result, '/tmp/test this')
+            self.assertEqual(result, '/tmp/test this'.encode('utf-8'))
 
     def test_unicode_in_uri(self):
         if sys.platform == 'win32':
             result = path.uri_to_path('file:///C://%C3%A6%C3%B8%C3%A5')
-            self.assertEqual(result, 'C:/æøå')
+            self.assertEqual(result, 'C:/æøå'.encode('utf-8'))
         else:
             result = path.uri_to_path('file:///tmp/%C3%A6%C3%B8%C3%A5')
-            self.assertEqual(result, '/tmp/æøå')
+            self.assertEqual(result, '/tmp/æøå'.encode('utf-8'))
+
+    def test_latin1_in_uri(self):
+        if sys.platform == 'win32':
+            result = path.uri_to_path('file:///C://%E6%F8%E5')
+            self.assertEqual(result, 'C:/æøå'.encode('latin-1'))
+        else:
+            result = path.uri_to_path('file:///tmp/%E6%F8%E5')
+            self.assertEqual(result, '/tmp/æøå'.encode('latin-1'))
 
 
 class SplitPathTest(unittest.TestCase):
@@ -177,11 +201,11 @@ class FindFilesTest(unittest.TestCase):
         self.assertEqual(len(files), 1)
         self.assert_(files[0], path_to_data_dir('blank.mp3'))
 
-    def test_names_are_unicode(self):
-        is_unicode = lambda f: isinstance(f, unicode)
+    def test_names_are_bytestrings(self):
+        is_bytes = lambda f: isinstance(f, bytes)
         for name in self.find(''):
             self.assert_(
-                is_unicode(name), '%s is not unicode object' % repr(name))
+                is_bytes(name), '%s is not bytes object' % repr(name))
 
     def test_ignores_hidden_folders(self):
         self.assertEqual(self.find('.hidden'), [])
